/*
 * Set/Get rounding mode wrapper function for R
 * 
 * Copyright 2010,2011 Gianluca Amato
 */

void r_fegetround(int *rounding_mode);
void r_fesetround(int *rounding_mode);
